from elevenlabs.endpoint import Endpoint

class TTS(Endpoint):
    """ I was winging this whole library, so I thought to match the API
        documentation one-to-one, but I realized I could do better. I could make
        it far more Pythonic. So I probably won't be using this now. """
